******************************************************************************
*Author      : Daniel B. Hall (c)opyright 1995
*Procedure   : DBF2RTF
*File        : DBF2RTF.PRG
*Class       : Documentation Utility
*Overlay     : System
*Purpose     : Create a Windows RTF Help file from a DBF File.
*Calls       : 
*Called From : 
*Example     : DO DBF2RTF with 'HELP','TOPIC','DETAILS','RTFFILE.RTF','ARIAL','18','ARIAL','10','24'
*Notes       : This procedure will take a DBF file with actually two fields
*			   a Topic and a Detail field and convert them to a Windows RTF Help File.
*
*Local Vars  : ln_lstrec		- Used to determine percentage
*			   
*Windows	 : Perc_Wind		- Used to display messages and Status Bar
*
*      Variable    Type   Length   Description
*PARA1 lc_dbf	    C        ?     Actual DBF file to convert
*PARA2 lc_topic	    C        ?     This is the header topic field
*PARA3 lc_detail    C        ?     This is the actual body text to display
*PARA4 lc_outfile   C        ?     The name of the RTF File to Convert.
*PARA5 lc_sysfont   C        ?     Name of the Windows Font to use for the Header/Topic
*PARA6 lc_fsize1	C        ?     Size of the Header/Topic Font
*PARA7 lc_sysfon2   C        ?     Name of the Windows Font to use for the Body
*PARA8 lc_fsize2    C        ?     Size of the Body Font
*
*Naming Conventions:			  {Memory Variables}
*						ln_		- refers to Local Numeric Variable
*						lc_		- refers to Local Character Variable
*						lb_		- refers to Local Logical/Boolean Variable
*						ld_		- refers to Local Date Variable
*
*Code Lines:			155
********************************************************************************
PARA  lc_dbf,lc_topic,lc_detail,lc_outfile,lc_sysfont,lc_fsize1,lc_sysfon2,lc_fsize2
SET MEMOWIDTH TO 90
CLOSE ALL
CLEA
SET TALK OFF
SET SAFETY OFF
* Check Parameters
IF EMPT(lc_sysfont)
  lc_sysfont = 'Arial'	&&Select Arial if header font empty
ENDI
IF EMPT(lc_fsize1)
  lc_fsize1  = '48'		&&Select font size 24 if font size empty
ELSE
  lc_fsize1  = ALLT(STR(VAL(lc_fsize1)*2,3))
ENDI
IF EMPT(lc_sysfon2)
  lc_sysfon2 = 'Arial'	&&Select Arial if body font empty
ENDI
IF EMPT(lc_fsize2)
  lc_fsize2  = '20'		&&Select font size 24 if font size empty
ELSE
  lc_fsize2  = ALLT(STR(VAL(lc_fsize2)*2,3))
ENDI

USE (lc_dbf)
INDEX ON &lc_topic TO TMPFILE
M->lc_Type      = '{\rtf1\ansi '                       	&&Set type of RTF File
M->lc_fonttbl   = '\deff1{\fonttbl'                 	&&Start font def.
M->lc_font0     = '{\f0\froman '+ALLT(lc_sysfont)+';}'  &&Define font 0
M->lc_font1     = '{\f1\fswiss '+ALLT(lc_sysfon2)+';}}' &&Define font 1
M->lc_coltbl    = '{\colortbl '+;                    	
                   '\red0\green0\blue255;'+;
                   '\red0\green0\blue0;'+;
                   '\red255\green0\blue0;}'				&&Define color table
M->lc_stylesheet=  '{\stylesheet'

M->lc_style0    =  '{\s0\f0\fs72\cf0\b\i\lotusoutlinelevel0\keep\keepn'+CHR(13)+CHR(10)+'\snext9 Heading;}'
M->lc_style1    =  '{\s1\f0\cf1\lotusoutlinelevel0 \li144 Topic1;}'
M->lc_style2    =  '{\s2\f0\cf1\lotusoutlinelevel0 \li144 Topic2;}'
M->lc_style3    =  '{\s3\f0\cf1\lotusoutlinelevel0 \li144 Topic3;}'
M->lc_style4    =  '{\s4\f0\cf1\lotusoutlinelevel0 \li144 Topic4;}'
M->lc_style5    =  '{\s5\f0\cf1\lotusoutlinelevel0 \li360 Cross Ref;}'
M->lc_style6    =  '{\s6'+CHR(13)+CHR(10)+'\f0\cf1\lotusoutlinelevel0 \li144 Macro;}'
M->lc_style7    =  '{\s7\f0\cf1\lotusoutlinelevel0 \ri3600 NarrowPopUp;}'
M->lc_style8    =  '{\s8\f0\cf1\sa144\lotusoutlinelevel0 \li720 Indent .35;}'
M->lc_style9    =  '{\s9\fs20\cf2\lotusoutlinelevel0 Body Text;}'
M->lc_style10   =  '{\s10\f0\cf1\lotusoutlinelevel0 \fi720 Footnote;}}'
M->lc_pginfo    =  '\ftnbj \landscape \paperw15840\paperh12240 \margl1440 \margr1440 \sectd '
M->lc_Topic1    =  ''
M->lc_Topic2    =  ''
M->lc_Topic3    =  ''
M->lc_Topic4    =  ''
M->lc_newln     =  '\par '
M->lc_nextpg    =  '\par \page '
M->ln_idx       =  0

File_name=fcreate(lc_outfile)

=FWRITE(file_name,M->lc_type)
=FWRITE(file_name,M->lc_fonttbl+M->lc_font0+M->lc_font1)
=FWRITE(file_name,M->lc_coltbl)
=FWRITE(file_name,M->lc_stylesheet)
=FWRITE(file_name,M->lc_style0)
=FWRITE(file_name,M->lc_style1)
=FWRITE(file_name,M->lc_style2)
=FWRITE(file_name,M->lc_style3)
=FWRITE(file_name,M->lc_style4)
=FWRITE(file_name,M->lc_style5)
=FWRITE(file_name,M->lc_style6)
=FWRITE(file_name,M->lc_style7)
=FWRITE(file_name,M->lc_style8)
=FWRITE(file_name,M->lc_style9)
=FWRITE(file_name,M->lc_style10)
=FWRITE(file_name,M->lc_pginfo)

&&Set up Index
M->ln_idx = 0
M->lc_Topic1    =  '{\up6 #{\footnote \pard\plain \s1\f0\cb0\lotusoutlinelevel0 \li144 {\up6 #}INDEX}}'
M->lc_Topic2    =  '{\up6 ${\footnote \pard\plain \s2\f0\cb0\lotusoutlinelevel0 \li144 {\up6 $}Index}}'
M->lc_Topic3    =  '{\up6 K{\footnote \pard\plain \s3\f0\cb0\lotusoutlinelevel0 \li144 {\up6 K}Index}}'
M->lc_Topic4    =  '{\up6 +{\footnote \pard\plain \s4\f0\cb0\lotusoutlinelevel0 \li144 {\up6 +}Index}}\pard\plain \s0\f0\fs'+lc_fsize1+'\cf0\b\i\lotusoutlinelevel0\keep\keepn\snext9 Index'
M->lc_txtlayout =  '\pard\plain'+CHR(10)+CHR(13)+'\s9\fs'+lc_fsize1+'\cf2\lotusoutlinelevel0'+CHR(13)+CHR(10)
=FPUTS(file_name,M->lc_Topic1)
=FPUTS(file_name,M->lc_Topic2)
=FPUTS(file_name,M->lc_Topic3)
=FPUTS(file_name,M->lc_Topic4)
=FPUTS(file_name,M->lc_txtlayout)
M->lc_idxlet = ''
SCAN
  IF M->lc_idxlet <> LEFT(&lc_topic,1)
    =FPUTS(file_name,'\par \fs'+lc_fsize1+LEFT(&lc_topic,1)+'...................'+CHR(13)+CHR(10))
  ENDI  
  M->ln_idx = M->ln_idx + 1
  =FPUTS(file_name,'\par \fs'+lc_fsize2+' {\uldb '+STRTR(STRTR(STRTR(ALLT(&lc_topic),'\','\\'),'{','\{'),'}','\}')+'}{\v '+ALLT(STR(M->ln_idx,4))+'}')
  M->lc_idxlet = LEFT(&lc_topic,1)
ENDSCAN

=FPUTS(file_name,M->lc_nextpg)

M->ln_idx = 0
M->lc_txtlayout =  '\par \pard\plain'+CHR(10)+CHR(13)+'\s9\fs'+lc_fsize2+'\cf2\lotusoutlinelevel0'+CHR(13)+CHR(10)&&+'\par '
SCAN 
  M->ln_idx = M->ln_idx + 1
  M->lc_Topic1    =  '{\up6 #{\footnote \pard\plain \s1\f0\cb0\lotusoutlinelevel0 \li144 {\up6 #}'+ALLT(STR(M->ln_idx))+'}}'
  M->lc_Topic2    =  '{\up6 ${\footnote \pard\plain \s2\f0\cb0\lotusoutlinelevel0 \li144 {\up6 $}'+ALLT(&lc_topic)+'}}'
  M->lc_Topic3    =  '{\up6 K{\footnote \pard\plain \s3\f0\cb0\lotusoutlinelevel0 \li144 {\up6 K}'+ALLT(&lc_topic)+'}}'
  M->lc_Topic4    =  '{\up6 +{\footnote \pard\plain \s4\f0\cb0\lotusoutlinelevel0 \li144 {\up6 +}'+ALLT(STR(M->ln_idx,4))+'}}\pard\plain \s0\f0\fs'+lc_fsize1+'\cf0\b\i\lotusoutlinelevel0\keep\keepn\snext9 '+&lc_topic
  =FPUTS(file_name,M->lc_Topic1)
  =FPUTS(file_name,M->lc_Topic2)
  =FPUTS(file_name,M->lc_Topic3)
  =FPUTS(file_name,M->lc_Topic4)
  =FPUTS(file_name,M->lc_txtlayout)
  WAIT WINDOW 'Converting Topic: '+ALLT(&lc_topic) NOWAIT
  FOR M->ln_count = 1 TO MEMLINE(&lc_detail)
    =FPUTS(file_name,'\par '+STRTR(STRTR(STRTR(MLINE(&lc_detail,M->ln_count),'\','\\'),'{','\{'),'}','\}'))
  ENDF  
  =FPUTS(file_name,M->lc_nextpg)  
ENDS
=FWRITE(file_name,'}')
=fclose(File_name)


